/// <reference types="node" />
import * as tapable from "tapable";
import { Callback } from "tapable";
import Watching from "./watching";
import type { WatchOptions } from "./config/watch";
import { RspackOptionsNormalized } from "./config";
import { Stats } from "./stats";
import { Compilation } from "./compilation";
import ResolverFactory from "./ResolverFactory";
import { WatchFileSystem } from "./util/fs";
declare class Compiler {
    #private;
    webpack: any;
    compilation: Compilation;
    root: Compiler;
    running: boolean;
    resolverFactory: ResolverFactory;
    infrastructureLogger: any;
    watching: Watching;
    outputPath: string;
    name: string;
    inputFileSystem: any;
    outputFileSystem: any;
    watchFileSystem: WatchFileSystem;
    intermediateFileSystem: any;
    watchMode: boolean;
    context: string;
    modifiedFiles?: ReadonlySet<string>;
    removedFiles?: ReadonlySet<string>;
    hooks: {
        done: tapable.AsyncSeriesHook<Stats>;
        afterDone: tapable.SyncHook<Stats>;
        compilation: tapable.SyncHook<Compilation>;
        thisCompilation: tapable.SyncHook<[Compilation]>;
        invalid: tapable.SyncHook<[string | null, number]>;
        compile: tapable.SyncHook<[any]>;
        initialize: tapable.SyncHook<[]>;
        infrastructureLog: tapable.SyncBailHook<[string, string, any[]], true>;
        beforeRun: tapable.AsyncSeriesHook<[Compiler]>;
        run: tapable.AsyncSeriesHook<[Compiler]>;
        emit: tapable.AsyncSeriesHook<[Compilation]>;
        afterEmit: tapable.AsyncSeriesHook<[Compilation]>;
        failed: tapable.SyncHook<[Error]>;
        watchRun: tapable.AsyncSeriesHook<[Compiler]>;
        watchClose: tapable.SyncHook<[]>;
        environment: tapable.SyncHook<[]>;
        afterEnvironment: tapable.SyncHook<[]>;
        afterPlugins: tapable.SyncHook<[Compiler]>;
        afterResolvers: tapable.SyncHook<[Compiler]>;
    };
    options: RspackOptionsNormalized;
    constructor(context: string, options: RspackOptionsNormalized);
    getInfrastructureLogger(name: string | Function): any;
    run(callback: Callback<Error, Stats>): void;
    build(cb: (error?: Error) => void): void;
    rebuild(modifiedFiles: ReadonlySet<string>, removedFiles: ReadonlySet<string>, cb: (error?: Error) => void): void;
    watch(watchOptions: WatchOptions, handler: (error: Error, stats: Stats) => void): Watching;
    purgeInputFileSystem(): void;
    /**
     * @todo
     */
    close(callback: any): void;
    emitAssets(compilation: Compilation, callback: any): void;
    getAsset(name: string): Buffer;
}
export { Compiler };
//# sourceMappingURL=compiler.d.ts.map