"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNormalizedRspackOptions = void 0;
const entry_1 = require("./entry");
const devtool_1 = require("./devtool");
const target_1 = require("./target");
const output_1 = require("./output");
const module_1 = require("./module");
const builtins_1 = require("./builtins");
const resolve_1 = require("./resolve");
const snapshot_1 = require("./snapshot");
const cache_1 = require("./cache");
const stats_1 = require("./stats");
const optimization_1 = require("./optimization");
const experiments_1 = require("./experiments");
const node_1 = require("./node");
function getNormalizedRspackOptions(config, getCompiler) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const context = (_a = config.context) !== null && _a !== void 0 ? _a : process.cwd();
    const mode = (_b = config.mode) !== null && _b !== void 0 ? _b : "production";
    const entry = (0, entry_1.resolveEntryOptions)(config.entry, {
        context
    }, (_c = config.optimization) === null || _c === void 0 ? void 0 : _c.runtimeChunk);
    const output = (0, output_1.resolveOutputOptions)(config.output);
    const target = (0, target_1.resolveTargetOptions)(config.target);
    const externals = (_d = config.externals) !== null && _d !== void 0 ? _d : {};
    const externalsType = (_e = config.externalsType) !== null && _e !== void 0 ? _e : "";
    const plugins = (_f = config.plugins) !== null && _f !== void 0 ? _f : [];
    const builtins = (0, builtins_1.resolveBuiltinsOptions)(config.builtins || {}, {
        contextPath: context,
        isProduction: mode === "production"
    });
    const resolve = (0, resolve_1.resolveResolveOptions)(config.resolve, { target });
    const devtool = (0, devtool_1.resolveDevtoolOptions)(config.devtool);
    const module = (0, module_1.resolveModuleOptions)(config.module, {
        devtool,
        context,
        target,
        getCompiler
    });
    const stats = (0, stats_1.resolveStatsOptions)(config.stats);
    const devServer = config.devServer;
    const snapshot = (0, snapshot_1.resolveSnapshotOptions)(config.snapshot);
    const cache = (0, cache_1.resolveCacheOptions)((_g = config.cache) !== null && _g !== void 0 ? _g : (mode === "production" ? false : true));
    const optimization = (0, optimization_1.resolveOptimizationOptions)((_h = config.optimization) !== null && _h !== void 0 ? _h : {}, mode);
    const experiments = (0, experiments_1.resolveExperiments)(config.experiments);
    const node = (0, node_1.resolveNode)(config.node);
    return {
        ...config,
        context,
        mode,
        devServer,
        entry,
        output,
        target,
        externals,
        externalsType,
        plugins,
        builtins,
        module,
        resolve,
        devtool,
        infrastructureLogging: cloneObject(config.infrastructureLogging),
        stats,
        snapshot,
        cache,
        optimization,
        experiments,
        node
    };
}
exports.getNormalizedRspackOptions = getNormalizedRspackOptions;
function cloneObject(value) {
    return { ...value };
}
//# sourceMappingURL=index.js.map